Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteItems ¶
func DeleteItems()
DeleteItems shows an example, how to delete multiple items by keys
func GetFromGlobalIndex ¶
func GetFromGlobalIndex()
GetFromGlobalIndex shows an example, how to get item from global index
func GetItemsFromGlobalIndex ¶
func GetItemsFromGlobalIndex()
GetItemsFromGlobalIndex shows an example, how to get multiple items from global index
func SaveItemsWithContext ¶ added in v0.3.0
func SaveItemsWithContext()
SaveItemsWithContext(context.Background(), shows an example, how to save multiple items
Types ¶
Click to show internal directories.
Click to hide internal directories.